# Torii Backends

```{warning}
The Torii API reference is a work in progress and we are actively working on improving it,
however it may be deficient or missing in places.
```

Torii has 3 primary backends, each takes the IR and generates an RTL netlist.

```{toctree}
:maxdepth: 2

cxxrtl
rtlil
verilog

```
